@@ -2,6 +2,8 @@
 #'
 #' @description
 #' This function computes the Equalized Odds metric
+#' 
+#' Formula: TP / (TP + FN)
 #'
 #' @details
 #' This function computes the Equalized Odds metric (also known as Equal Opportunity, Positive Rate Parity or Separation). Equalized Odds are calculated
@@ -12,16 +14,15 @@
 #' sensitivities will be reflected in numbers lower than 1 in the returned named vector, thus numbers
 #' lower than 1 mean WORSE prediction for the subgroup.
 #'
-#' @param data The dataframe that contains the necessary columns.
-#' @param outcome The column name of the actual outcomes.
-#' @param group Sensitive group to examine.
-#' @param probs The column name or vector of the predicted probabilities (numeric between 0 - 1). If not defined, argument preds needs to be defined.
-#' @param preds The column name or vector of the predicted binary outcome (0 or 1). If not defined, argument probs needs to be defined.
-#' @param preds_levels The desired levels of the predicted binary outcome. If not defined, levels of the outcome variable are used.
-#' @param outcome_base Base level for the target variable used to compute fairness metrics. Default is the first level of the outcome variable.
-#' @param cutoff Cutoff to generate predicted outcomes from predicted probabilities. Default set to 0.5.
-#' @param base Base level for sensitive group comparison.
+#' @param data Data.frame that contains the necessary columns.
+#' @param group Column name indicating the sensitive group (character).
+#' @param base Base level of the sensitive group (character).
 #' @param group_breaks If group is continuous (e.g., age): either a numeric vector of two or more unique cut points or a single number >= 2 giving the number of intervals into which group feature is to be cut.
+#' @param outcome Column name indicating the binary outcome variable (character).
+#' @param outcome_base Base level of the outcome variable (i.e., negative class). Default is the first level of the outcome variable.
+#' @param probs Column name or vector with the predicted probabilities (numeric between 0 - 1). Either probs or preds need to be supplied.
+#' @param preds Column name or vector with the predicted binary outcome (0 or 1). Either probs or preds need to be supplied.
+#' @param cutoff Cutoff to generate predicted outcomes from predicted probabilities. Default set to 0.5.
 #'
 #' @name equal_odds
 #'
@@ -33,19 +34,17 @@
 #'
 #' @examples
 #' data(compas)
-#' equal_odds(data = compas, outcome = 'Two_yr_Recidivism', group = 'ethnicity',
-#' probs = 'probability', preds = NULL, preds_levels = c('no', 'yes'),
-#' cutoff = 0.4, base = 'Caucasian')
-#' equal_odds(data = compas, outcome = 'Two_yr_Recidivism', group = 'ethnicity',
-#' probs = NULL, preds = 'predicted', preds_levels = c('no', 'yes'),
-#' cutoff = 0.5, base = 'Hispanic')
+#' compas$Two_yr_Recidivism_01 <- ifelse(compas$Two_yr_Recidivism == 'yes', 1, 0) 
+#' equal_odds(data = compas, outcome = 'Two_yr_Recidivism_01', group = 'ethnicity',
+#' probs = 'probability', cutoff = 0.4, base = 'Caucasian')
+#' equal_odds(data = compas, outcome = 'Two_yr_Recidivism_01', group = 'ethnicity',
+#' preds = 'predicted', cutoff = 0.5, base = 'Hispanic')
 #'
 #' @export
 
 equal_odds <- function(data, outcome, group,
                        probs = NULL, 
                        preds = NULL, 
-                       preds_levels = NULL, 
                        outcome_base = NULL, 
                        cutoff = 0.5, 
                        base = NULL,
@@ -85,15 +84,15 @@ equal_odds <- function(data, outcome, group,
         }
     }
     
+    # convert to factor
     group_status   <- as.factor(data[, group])
     outcome_status <- as.factor(data[, outcome])
     
-    if (is.null(preds_levels)) {
-        preds_levels <- levels(outcome_status)
-    }
-    levels(preds_status) <- preds_levels
-    outcome_status <- relevel(outcome_status, preds_levels[1])
-    preds_status   <- relevel(preds_status,   preds_levels[1])
+    # relevel preds & outcomes
+    if (is.null(outcome_base)) {outcome_base <- levels(outcome_status)[1]}
+    outcome_status   <- relevel(outcome_status, outcome_base)
+    preds_status     <- relevel(preds_status,   outcome_base)
+    outcome_positive <- levels(outcome_status)[2]
     
     # check lengths
     if ((length(outcome_status) != length(preds_status)) | (length(outcome_status) !=
@@ -111,18 +110,13 @@ equal_odds <- function(data, outcome, group,
     val         <- rep(NA, length(levels(group_status)))
     names(val)  <- levels(group_status)
     sample_size <- val
-    
-    # set outcome base
-    if (is.null(outcome_base)) {
-        outcome_base <- levels(preds_status)[1]
-    }
 
     # compute value for all groups
     for (i in levels(group_status)) {
         cm <- caret::confusionMatrix(preds_status[group_status   == i], 
                                      outcome_status[group_status == i], 
                                      mode = 'everything', 
-                                     positive = outcome_base)
+                                     positive = outcome_positive)
         metric_i       <- cm$byClass['Sensitivity']
         val[i]         <- metric_i
         sample_size[i] <- sum(cm$table)
