@@ -2,6 +2,8 @@
 #'
 #' @description
 #' This function computes the False Positive Rate (FPR) parity metric
+#' 
+#' Formula: FP / (TN + FP)
 #'
 #' @details
 #' This function computes the False Positive Rate (FPR) parity metric as described by Chouldechova 2017. False positive rates are calculated
@@ -11,16 +13,15 @@
 #' false positives error rates will be reflected in numbers lower than 1 in the returned named vector, thus numbers
 #' lower than 1 mean BETTER prediction for the subgroup.
 #'
-#' @param data The dataframe that contains the necessary columns.
-#' @param outcome The column name of the actual outcomes.
-#' @param group Sensitive group to examine.
-#' @param probs The column name or vector of the predicted probabilities (numeric between 0 - 1). If not defined, argument preds needs to be defined.
-#' @param preds The column name or vector of the predicted binary outcome (0 or 1). If not defined, argument probs needs to be defined.
-#' @param preds_levels The desired levels of the predicted binary outcome. If not defined, levels of the outcome variable are used.
-#' @param outcome_base Base level for the target variable used to compute fairness metrics. Default is the first level of the outcome variable.
-#' @param cutoff Cutoff to generate predicted outcomes from predicted probabilities. Default set to 0.5.
-#' @param base Base level for sensitive group comparison.
+#' @param data Data.frame that contains the necessary columns.
+#' @param group Column name indicating the sensitive group (character).
+#' @param base Base level of the sensitive group (character).
 #' @param group_breaks If group is continuous (e.g., age): either a numeric vector of two or more unique cut points or a single number >= 2 giving the number of intervals into which group feature is to be cut.
+#' @param outcome Column name indicating the binary outcome variable (character).
+#' @param outcome_base Base level of the outcome variable (i.e., negative class). Default is the first level of the outcome variable.
+#' @param probs Column name or vector with the predicted probabilities (numeric between 0 - 1). Either probs or preds need to be supplied.
+#' @param preds Column name or vector with the predicted binary outcome (0 or 1). Either probs or preds need to be supplied.
+#' @param cutoff Cutoff to generate predicted outcomes from predicted probabilities. Default set to 0.5.
 #'
 #' @name fpr_parity
 #'
@@ -31,22 +32,20 @@
 #'
 #' @examples
 #' data(compas)
-#' fpr_parity(data = compas, outcome = 'Two_yr_Recidivism', group = 'ethnicity',
-#' probs = 'probability', preds = NULL, preds_levels = c('no', 'yes'),
-#' cutoff = 0.4, base = 'Caucasian')
-#' fpr_parity(data = compas, outcome = 'Two_yr_Recidivism', group = 'ethnicity',
-#' probs = NULL, preds = 'predicted', preds_levels = c('no', 'yes'),
-#' cutoff = 0.5, base = 'Hispanic')
+#' compas$Two_yr_Recidivism_01 <- ifelse(compas$Two_yr_Recidivism == 'yes', 1, 0) 
+#' fpr_parity(data = compas, outcome = 'Two_yr_Recidivism_01', group = 'ethnicity',
+#' probs = 'probability', cutoff = 0.4, base = 'Caucasian')
+#' fpr_parity(data = compas, outcome = 'Two_yr_Recidivism_01', group = 'ethnicity',
+#' preds = 'predicted', cutoff = 0.5, base = 'Hispanic')
 #'
 #' @export
 
 fpr_parity <- function(data, outcome, group,
-                       probs = NULL, 
-                       preds = NULL, 
-                       preds_levels = NULL, 
+                       probs        = NULL, 
+                       preds        = NULL, 
                        outcome_base = NULL, 
-                       cutoff = 0.5, 
-                       base = NULL,
+                       cutoff       = 0.5, 
+                       base         = NULL,
                        group_breaks = NULL) {
     
     # check if data is data.frame
@@ -83,15 +82,15 @@ fpr_parity <- function(data, outcome, group,
         }
     }
     
+    # convert to factor
     group_status   <- as.factor(data[, group])
     outcome_status <- as.factor(data[, outcome])
     
-    if (is.null(preds_levels)) {
-        preds_levels <- levels(outcome_status)
-    }
-    levels(preds_status) <- preds_levels
-    outcome_status <- relevel(outcome_status, preds_levels[1])
-    preds_status   <- relevel(preds_status,   preds_levels[1])
+    # relevel preds & outcomes
+    if (is.null(outcome_base)) {outcome_base <- levels(outcome_status)[1]}
+    outcome_status   <- relevel(outcome_status, outcome_base)
+    preds_status     <- relevel(preds_status,   outcome_base)
+    outcome_positive <- levels(outcome_status)[2]
 
     # check lengths
     if ((length(outcome_status) != length(preds_status)) | (length(outcome_status) !=
@@ -100,29 +99,22 @@ fpr_parity <- function(data, outcome, group,
     }
 
     # relevel group
-    if (is.null(base)) {
-        base <- levels(group_status)[1]
-    }
+    if (is.null(base)) {base <- levels(group_status)[1]}
     group_status <- relevel(group_status, base)
 
     # placeholders
     val         <- rep(NA, length(levels(group_status)))
     names(val)  <- levels(group_status)
     sample_size <- val
-    
-    # set outcome base
-    if (is.null(outcome_base)) {
-        outcome_base <- levels(preds_status)[1]
-    }
 
     # compute value for all groups
     for (i in levels(group_status)) {
-        cm <- caret::confusionMatrix(preds_status[group_status == i], 
+        cm <- caret::confusionMatrix(preds_status[group_status   == i], 
                                      outcome_status[group_status == i], 
-                                     mode = 'everything',
-                                     positive = outcome_base)
+                                     mode     = 'everything',
+                                     positive = outcome_positive)
         cm_positive <- cm$positive
-        cm_negative <- preds_levels[!(preds_levels %in% cm_positive)]
+        cm_negative <- levels(outcome_status)[!(levels(outcome_status) %in% cm_positive)]
         TP <- cm$table[cm_positive, cm_positive]
         TN <- cm$table[cm_negative, cm_negative]
         FP <- cm$table[cm_positive, cm_negative]
